/*
	This do file constructs measures of upstream and downstream import exposure
	Note on nomenclature: sic87dd_down denotes industries purchasing the good; sic87dd_up denotes industries producing the good.
	
	This do file is a slightly modified version of "/AADHP-JOLE-Sag-Replication-2015-05-13/do/build/national/io_exposure.do" written by Brendan Price
	The only difference is that they saved their data in wide format while we save data in long format.	

	Last edited: November 21, 2017
	
*/

set more off
set matsize 1000
clear all

* Define Directories
local dir "..." //Insert your directory path
local iodir "`dir'/AGNR-JobFlowsChinaShock/data/io/"
local tradedir "`dir'/AGNR-JobFlowsChinaShock/data/trade/"

/* Compute first-order upstream trade exposure (propagating upstream from an industry's customers) and downstream trade exposure (propagating downstream from its suppliers) */

foreach d in "up" "down" {
	* Load the matrix of input output data
	use "`iodir'raw/shares/gross_shares_AADHP.dta", clear
	
	if "`d'" == "up" {
		* Compute and retain the fraction of sales that go to (1) manuf, (2) non-manuf, and (3) residual category
		bysort sic87dd_up: egen manuf_sales = total(produce_share * (sic87dd_down >= 2000 & sic87dd_down <= 3999))
		bysort sic87dd_up: egen nonmanuf_sales = total(produce_share * (sic87dd_down < 2000 | (sic87dd_down > 3999 & sic87dd_down < .)))
		bysort sic87dd_up: egen resid_sales = total(produce_share * (sic87dd_down == .))

		label var manuf_sales "Share of sales made to mfg industries"
		label var nonmanuf_sales "Share of sales made to non-mfg industries"
		label var resid_sales "Share of sales made to residual categories"
		local extra_vars "manuf_sales nonmanuf_sales resid_sales"

		* Sales shares should sum to unity
		assert abs(1 - (manuf_sales + nonmanuf_sales + resid_sales)) < .001

		* Integrating out downstream firms
		rename sic87dd_down sic87dd
		local w "produce_share"

		* Variable that will remain after "integration"
		local indvar "sic87dd_up"
	}
	else if "`d'" == "down" {
		* Compute and retain the fraction of purchases that are from (1) manuf, (2) non-manuf, and (3) residual category
		bysort sic87dd_down: egen manuf_purchases = total(purchase_share * (sic87dd_up >= 2000 & sic87dd_up <= 3999))
		bysort sic87dd_down: egen nonmanuf_purchases = total(purchase_share * (sic87dd_up < 2000 | (sic87dd_up > 3999 & sic87dd_up < .)))
		bysort sic87dd_down: egen resid_purchases = total(purchase_share * (sic87dd_up == .))

		label var manuf_purchases "Purchases from mfg industries divided by total sales"
		label var nonmanuf_purchases "Purchases from non-mfg industries divided by total sales"
		label var resid_purchases "Purchases from residual categories divided by total sales"
		local extra_vars "manuf_purchases nonmanuf_purchases resid_purchases"

		* Note that "purchase shares" don't sum to unity because they are normalized by total SALES, not total purchases.
		* However, it's important that these shares sum to less than unity across manufacturing.
		assert manuf_purchases <= 1

		* Integrating out upstream firms
		rename sic87dd_up sic87dd
		local w "purchase_share"

		* Variable that will remain after "integration"
		local indvar "sic87dd_down"
	}

	* Merge in trade variables
	merge m:1 sic87dd using "`tradedir'raw/main_AADHP.dta",  keepusing(sic87dd* manuf cbp_emp* l_import* real_market1991 d_import*) nogenerate

	drop cbp_emp_estab*

	gen real_market1988= (l_import_otch_2011 - l_import_otch_1991) * real_market1991 / (20 * d_import_otch_1991_2011)
	replace real_market1988 = (l_import_otch_2007 - l_import_otch_1999) * real_market1991 / (8 * d_import_otch_1999_2007) if sic87dd==2021
	gen ratiorm9188 = real_market1991 / real_market1988

	drop d_*

	* Trade variables should be missing for all non-manuf industries, non-missing for all manuf industries.
	* Treat non-manufacturing industries as experiencing null trade exposure in all periods.
	foreach var of varlist l_import_* ratiorm9188 {
		assert `var' == . if sic87dd < 2000 | sic87dd > 3999
		replace `var' = 0 if `var' == . | sic87dd < 2000 | sic87dd > 3999
	}

	forvalues t = 1991/2011 {
		* Construct measures of upstream/downstream import exposure
		bysort `indvar': egen l_import_`d'_usch_`t' = total(`w' * l_import_usch_`t')
		label var l_import_`d'_usch_`t' "First-order `d'stream import exposure defined using gross flows"

		* Instrument for upstream/downstream import exposure
		bysort `indvar': egen l_import_`d'_otch_`t' = total(`w' * l_import_otch_`t' * ratiorm9188)
		label var l_import_`d'_otch_`t' "First-order `d'stream instrument defined using gross flows"	
	}
	

	* Drop the "residual" sector (retained up until now to handle manufacturing industries that only ship to this sector)
	drop if `indvar' == .
	
	* Save a dataset of indirect import exposure measures
	keep `indvar' l_import_`d'_* `extra_vars'
	rename `indvar' sic87dd
	duplicates drop

	tempfile first_order_exposure_`d'
	save `first_order_exposure_`d'', replace
}


use `first_order_exposure_up', clear
merge 1:1 sic87dd using `first_order_exposure_down', assert(3) nogenerate
compress
tempfile first_order_exposure_wide
save `first_order_exposure_wide'


/* Now compute "full" measures of upstream/downstream import exposure incorporating higher-order effects */

foreach d in "up" "down" {
	* Load the matrix of input output data
	use "`iodir'raw/shares/leontief_shares_AADHP.dta", clear

	if "`d'" == "up" {
		* Integrating out downstream firms
		rename sic87dd_down sic87dd
		local w "produce_share"

		* Variable that will remain after "integration"
		local indvar "sic87dd_up"
	}
	else if "`d'" == "down" {
		* Integrating out upstream firms
		rename sic87dd_up sic87dd
		local w "purchase_share"
		
		* Variable that will remain after "integration"
		local indvar "sic87dd_down"
	}
	
	* Merge in trade variables (master observations should match manufacturing sector only)
	merge m:1 sic87dd using "`tradedir'raw/main_AADHP.dta",  keepusing(sic87dd* manuf cbp_emp* l_import* real_market1991 d_import*) nogenerate

	drop cbp_emp_estab*

	gen real_market1988= (l_import_otch_2011 - l_import_otch_1991) * real_market1991 / (20 * d_import_otch_1991_2011)
	replace real_market1988 = (l_import_otch_2007 - l_import_otch_1999) * real_market1991 / (8 * d_import_otch_1999_2007) if sic87dd==2021
	gen ratiorm9188 = real_market1991 / real_market1988

	drop d_*

	* Trade variables should be missing for all non-manuf industries, non-missing for all manuf industries.
	* Treat non-manufacturing industries as experiencing null trade exposure in all periods.
	foreach var of varlist l_import_* ratiorm9188 {
		assert `var' == . if sic87dd < 2000 | sic87dd > 3999
		replace `var' = 0 if `var' == . | sic87dd < 2000 | sic87dd > 3999
	}
	
	forvalues t = 1991/2011{
		* Construct measures of upstream/downstream import exposure
		bysort `indvar': egen l_import_`d'_LT_usch_`t' = total(`w' * l_import_usch_`t')
		label var l_import_`d'_LT_usch_`t' "Full `d'stream import exposure defined using gross flows"

		* Instrument for upstream/downstream import exposure
		bysort `indvar': egen l_import_`d'_LT_otch_`t' = total(`w' * l_import_otch_`t' * ratiorm9188)
		label var l_import_`d'_LT_otch_`t' "Full `d'stream instrument defined using gross flows"
		
	}
	
	
	keep `indvar' l_import_`d'_LT_* 
	rename `indvar' sic87dd
	duplicates drop

	* Save a dataset of indirect import exposure measures
	tempfile leontief_exposure_`d'
	save `leontief_exposure_`d''
}

use `leontief_exposure_up', clear
merge 1:1 sic87dd using `leontief_exposure_down', assert(3) nogenerate
compress
tempfile leontief_exposure_wide
save `leontief_exposure_wide'

/* Now transform data from wide to long to ensure compatibility with master trade and NETS employment data */

use `first_order_exposure_wide.dta', clear

keep sic87dd l_import*
reshape long l_import_up_usch_ l_import_up_otch_ l_import_down_usch_ l_import_down_otch_, i(sic87dd) j(year)

rename l_import_up_usch_ l_import_up_usch
rename l_import_up_otch_ l_import_up_otch
rename l_import_down_usch_ l_import_down_usch
rename l_import_down_otch_ l_import_down_otch

label var l_import_up_usch "First-order upstream U.S. imports from China/U.S. domestic demand in 1991"
label var l_import_up_otch "First-order upstream  Comparison countries' imports from China/U.S. domestic demand in 1988"
label var l_import_down_usch "First-order upstream U.S. imports from China/U.S. domestic demand in 1991"
label var l_import_down_otch "First-order upstream  Comparison countries' imports from China/U.S. domestic demand in 1988"
label var year ""


save "`iodir'clean/exposure/first_order_exposure.dta", replace




use `leontief_exposure_wide.dta', clear

keep sic87dd l_import*
reshape long l_import_up_LT_usch_ l_import_up_LT_otch_ l_import_down_LT_usch_ l_import_down_LT_otch_, i(sic87dd) j(year)

rename l_import_up_LT_usch_ l_import_up_LT_usch
rename l_import_up_LT_otch_ l_import_up_LT_otch
rename l_import_down_LT_usch_ l_import_down_LT_usch
rename l_import_down_LT_otch_ l_import_down_LT_otch

label var l_import_up_LT_usch "Full upstream U.S. imports from China/U.S. domestic demand in 1991"
label var l_import_up_LT_otch "Full upstream  Comparison countries' imports from China/U.S. domestic demand in 1988"
label var l_import_down_LT_usch "Full upstream U.S. imports from China/U.S. domestic demand in 1991"
label var l_import_down_LT_otch "Full upstream  Comparison countries' imports from China/U.S. domestic demand in 1988"
label var year ""

save "`iodir'clean/exposure/leontief_exposure.dta", replace
