/*
	This do file constructs measures of PNTR status. It takes NTR gaps from Pierce and Schott(2016) 
	and makes the measures compatible with AADHP's 392 manufacturing industries given by "SIC87DD"
	
	Last edited: November 21, 2017
	
*/


set more off
set matsize 1000
clear all


* Define Directories
local dir "..." //Insert your directory path
local iodir "`dir'/AGNR-JobFlowsChinaShock/data/io/"
local pntrdir "`dir'/AGNR-JobFlowsChinaShock/data/pntr/"
local xwalksdir "`dir'/AGNR-JobFlowsChinaShock/xwalks/"

* Load NTR gaps from Pierce and Schott (2016)
use "`pntrdir'raw/gaps_by_naics6_20150722_fam50_PS.dta", clear

* We use NTR gap of 1999
keep fam50 s1999
replace s1999 = 0 if s1999 == .

* Merge crosswalk to convert data in 4-digit SIC format
merge m:m fam50 using "`xwalksdir'fam_sic4/bbg_fam_drop_50_s4_2_PS.dta" 
keep if _merge == 3
drop _merge

rename s4 sic87
keep sic87 s1999

* This do file reclassfies certain industries. It comes from ".../AADHP-JOLE-Sag-Replication-2015-05-13/xwalks/ind/sic87_sic87dd/sic87_sic87dd.do", written by Brendan Price
do "`xwalksdir'sic87_sic87dd/sic87_sic87dd_AADHP.do"

collapse(mean) s1999, by(sic87dd)

gen manuf = 1 if sic87dd > 1999 & sic87dd < 4000
replace manuf = 0 if manuf == .

* This file contains further reclassification necessary before aggregating non-manufacturing industries.
merge m:m sic87dd using "`xwalksdir'sic87_sic87dd/sic87dd_to_sic87dd_pooled_pre.dta" 
drop if _merge == 2
drop _merge
assert sic_pooled_nmf == . if manuf == 1

replace sic87dd = sic_pooled_nmf if manuf == 0 & sic_pooled_nmf != . 
keep sic87dd s1999 manuf

collapse(mean) s1999, by(sic87dd)

gen manuf = 1 if sic87dd > 1999 & sic87dd < 4000
replace manuf = 0 if manuf == .

*This do file aggregates into 87 non-manufacturing industries. It comes from ".../AADHP-JOLE-Sag-Replication-2015-05-13/xwalks/ind/sic2io/sic87dd_to_sic87dd_pooled.dta" 
merge m:m sic87dd using "`xwalksdir'sic87_sic87dd/sic87dd_to_sic87dd_pooled_AADHP.dta" 

replace sic87dd = sic87dd_pooled if manuf == 0 
keep if sic87dd != .

collapse(mean) s1999, by(sic87dd)

gen manuf = 1 if sic87dd > 1999 & sic87dd < 4000
replace manuf = 0 if manuf == .

drop if sic87dd == 720 | sic87dd == 750 | sic87dd == 760 | sic87dd == 6720
replace s1999 = 0 if s1999 == .
replace s1999 = 0 if manuf == 0

tempfile spread_own
save `spread_own'


*****creating upstream and downstream measures of the NTR gap

foreach d in "up" "down" {
	* Load the matrix of input output data
	use "`iodir'raw/shares/gross_shares_AADHP.dta" 

	if "`d'" == "up" {
		* Compute and retain the fraction of sales that go to (1) manuf, (2) non-manuf, and (3) residual category
		bysort sic87dd_up: egen manuf_sales = total(produce_share * (sic87dd_down >= 2000 & sic87dd_down <= 3999))
		bysort sic87dd_up: egen nonmanuf_sales = total(produce_share * (sic87dd_down < 2000 | (sic87dd_down > 3999 & sic87dd_down < .)))
		bysort sic87dd_up: egen resid_sales = total(produce_share * (sic87dd_down == .))

		label var manuf_sales "Share of sales made to mfg industries"
		label var nonmanuf_sales "Share of sales made to non-mfg industries"
		label var resid_sales "Share of sales made to residual categories"
		local extra_vars "manuf_sales nonmanuf_sales resid_sales"

		* Sales shares should sum to unity
		*assert abs(1 - (manuf_sales + nonmanuf_sales + resid_sales)) < .001

		* Integrating out downstream firms
		rename sic87dd_down sic87dd
		local w "produce_share"

		* Variable that will remain after "integration"
		local indvar "sic87dd_up"
	}
	else if "`d'" == "down" {
		* Compute and retain the fraction of purchases that are from (1) manuf, (2) non-manuf, and (3) residual category
		bysort sic87dd_down: egen manuf_purchases = total(purchase_share * (sic87dd_up >= 2000 & sic87dd_up <= 3999))
		bysort sic87dd_down: egen nonmanuf_purchases = total(purchase_share * (sic87dd_up < 2000 | (sic87dd_up > 3999 & sic87dd_up < .)))
		bysort sic87dd_down: egen resid_purchases = total(purchase_share * (sic87dd_up == .))

		label var manuf_purchases "Purchases from mfg industries divided by total sales"
		label var nonmanuf_purchases "Purchases from non-mfg industries divided by total sales"
		label var resid_purchases "Purchases from residual categories divided by total sales"
		local extra_vars "manuf_purchases nonmanuf_purchases resid_purchases"

		* Note that "purchase shares" don't sum to unity because they are normalized by total SALES, not total purchases.
		* However, it's important that these shares sum to less than unity across manufacturing.
		*assert manuf_purchases <= 1

		* Integrating out upstream firms
		rename sic87dd_up sic87dd
		local w "purchase_share"

		* Variable that will remain after "integration"
		local indvar "sic87dd_down"
	}

		* Merge in trade variables (master observations should match manufacturing sector only)
		merge m:1 sic87dd using `spread_own'
		drop if _merge == 1
		drop _merge
	

		* Construct measures of upstream/downstream NTR gap
		bysort `indvar': egen `d'_spread = total(`w' * s1999)
		label var `d'_spread "First-order `d'stream NTR gap defined using gross flows"

	

	* Drop the "residual" sector (retained up until now to handle manufacturing industries that only ship to this sector)
	drop if `indvar' == .
	
	* Save a dataset of indirect measures
	keep `indvar' *spread
	rename `indvar' sic87dd
	duplicates drop

	tempfile first_order_`d'_spread
	save `first_order_`d'_spread'
}


*****creating higher-order upstream and downstream measures of the NTR gap


foreach d in "up" "down" {
	* Load the matrix of input output data
	use "`iodir'raw/shares/leontief_shares_AADHP.dta", clear

	if "`d'" == "up" {
		* Compute and retain the fraction of sales that go to (1) manuf, (2) non-manuf, and (3) residual category
		bysort sic87dd_up: egen manuf_sales = total(produce_share * (sic87dd_down >= 2000 & sic87dd_down <= 3999))
		bysort sic87dd_up: egen nonmanuf_sales = total(produce_share * (sic87dd_down < 2000 | (sic87dd_down > 3999 & sic87dd_down < .)))
		bysort sic87dd_up: egen resid_sales = total(produce_share * (sic87dd_down == .))

		label var manuf_sales "Share of sales made to mfg industries"
		label var nonmanuf_sales "Share of sales made to non-mfg industries"
		label var resid_sales "Share of sales made to residual categories"
		local extra_vars "manuf_sales nonmanuf_sales resid_sales"

		* Sales shares should sum to unity
		*assert abs(1 - (manuf_sales + nonmanuf_sales + resid_sales)) < .001

		* Integrating out downstream firms
		rename sic87dd_down sic87dd
		local w "produce_share"

		* Variable that will remain after "integration"
		local indvar "sic87dd_up"
	}
	else if "`d'" == "down" {
		* Compute and retain the fraction of purchases that are from (1) manuf, (2) non-manuf, and (3) residual category
		bysort sic87dd_down: egen manuf_purchases = total(purchase_share * (sic87dd_up >= 2000 & sic87dd_up <= 3999))
		bysort sic87dd_down: egen nonmanuf_purchases = total(purchase_share * (sic87dd_up < 2000 | (sic87dd_up > 3999 & sic87dd_up < .)))
		bysort sic87dd_down: egen resid_purchases = total(purchase_share * (sic87dd_up == .))

		label var manuf_purchases "Purchases from mfg industries divided by total sales"
		label var nonmanuf_purchases "Purchases from non-mfg industries divided by total sales"
		label var resid_purchases "Purchases from residual categories divided by total sales"
		local extra_vars "manuf_purchases nonmanuf_purchases resid_purchases"

		* Note that "purchase shares" don't sum to unity because they are normalized by total SALES, not total purchases.
		* However, it's important that these shares sum to less than unity across manufacturing.
		*assert manuf_purchases <= 1

		* Integrating out upstream firms
		rename sic87dd_up sic87dd
		local w "purchase_share"

		* Variable that will remain after "integration"
		local indvar "sic87dd_down"
	}

	* Merge in trade variables (master observations should match manufacturing sector only)
		merge m:1 sic87dd using `spread_own'
		drop if _merge == 1
		drop _merge
	

		* Construct measures of upstream/downstream NTR gap
		bysort `indvar': egen `d'_LT_spread = total(`w' * s1999)
		label var `d'_LT_spread "Higher-order `d'stream NTR gap defined using gross flows"

	

	* Drop the "residual" sector (retained up until now to handle manufacturing industries that only ship to this sector)
	drop if `indvar' == .
	
	* Save a dataset of indirect measures
	keep `indvar' *spread
	rename `indvar' sic87dd
	duplicates drop

	tempfile first_order_`d'_LT_spread
	save `first_order_`d'_LT_spread'
}


****merging all the different measures of NTR gap into one dataset
use `spread_own', clear
merge 1:1 sic87dd using `first_order_up_spread', nogenerate
merge 1:1 sic87dd using `first_order_down_spread', nogenerate
merge 1:1 sic87dd using `higher_order_up_spread', nogenerate
merge 1:1 sic87dd using `higher_order_down_spread', nogenerate

rename s1999 spread
label var spread "NTR gap 1999"
label var manuf "1 if manufacturing; 0 if non-manufacturing"

save "`pntrdir'clean/spread.dta", replace

