/*
	This do file constructs measures of chinese import exposyre. It takes these measures from 
	Acemoglu, Autor, Dorn, Hanson and Price (2016) and makes the measures compatible with our long data
	format and suitable for merging with NETS data and PNTR data
	
	Last edited: November 21, 2017
	
*/



set more off
set matsize 1000
clear all


* Define Directories
local dir "..." //Insert your directory path
local tradedir "`dir'/AGNR-JobFlowsChinaShock/data/trade/"
local iodir "`dir'/AGNR-JobFlowsChinaShock/data/io/"
local pntrdir "`dir'/AGNR-JobFlowsChinaShock/data/pntr/"

* Load main sample of AADHP
use "`tradedir'raw/main_AADHP.dta", clear 

keep sic87dd* manuf cbp_emp* l_import* real_market1991 d_import*
drop cbp_emp_estab*

* Calculating ratio of U.S. domestic demand in 1991 to 1988 to be useful later while constructing final measures of import exposure
gen real_market1988= (l_import_otch_2011 - l_import_otch_1991) * real_market1991 / (20 * d_import_otch_1991_2011)
replace real_market1988 = (l_import_otch_2007 - l_import_otch_1999) * real_market1991 / (8 * d_import_otch_1999_2007) if sic87dd==2021
gen ratiorm9188 = real_market1991 / real_market1988

drop d_*

* converting to long format
reshape long cbp_emp l_import_usch_ l_import_otch_, i(sic87dd) j(year)

rename l_import_usch_ l_import_usch
rename l_import_otch_ l_import_otch

label var sic87dd "4 digit SIC industry"
label var sic87dd_desc "SIC industry description"
label var l_import_usch "U.S. imports from China/U.S. domestic demand in 1991"
label var l_import_otch "Comparison countries' imports from China/U.S. domestic demand in 1988"
label var cbp_emp "employment levels from CBP"
label var manuf "1 if manufacturing; 0 if non-manufacturing"
label var real_market1991 "1991 U.S. real value of shipments + U.S. net imports"
label var real_market1988 "1988 U.S. real value of shipments + U.S. net imports"
label var ratiorm9188 "ratio of 1991 to 1988 U.S. real value of shipments + U.S. net imports"

* specifying panel
tsset sic87dd year

* generating measures of import exposure (7, 8 and 12 year differences)
foreach i in "7" "8" "12"{
	bysort sic87dd (year): gen d_import_usch_`i' = (l_import_usch - l_import_usch[_n-`i'])/`i'
	bysort sic87dd (year): gen d_import_otch_`i' = ((l_import_otch - l_import_otch[_n-`i'])/`i') * ratiorm9188

	label var d_import_usch_`i' "Change in U.S. imports from China; `i' year change"
	label var d_import_otch_`i' "Change in comparison countries' imports from China; `i' year change"
}


* merging in upstream and downstream measures of import exposure
merge 1:1 year sic87dd using "`iodir'clean/exposure/first_order_exposure.dta", nogenerate
merge 1:1 year sic87dd using "`iodir'clean/exposure/leontief_exposure.dta", nogenerate

tsset sic87dd year

foreach i in "7" "8" "12"{

	foreach d in "up" "down"{
		bysort sic87dd (year): gen d_`d'_usch_`i' = (l_import_`d'_usch - l_import_`d'_usch[_n-`i'])/`i'
		bysort sic87dd (year): gen d_`d'_otch_`i' = (l_import_`d'_otch - l_import_`d'_otch[_n-`i'])/`i'

		label var d_`d'_usch_`i' "First-order `d'stream change in U.S. imports from China;`i' year change"
		label var d_`d'_otch_`i' "First-order `d'stream change in comparison countries' imports from China; `i' year change"

		bysort sic87dd (year): gen d_`d'_LT_usch_`i' = (l_import_`d'_LT_usch - l_import_`d'_LT_usch[_n-`i'])/`i'
		bysort sic87dd (year): gen d_`d'_LT_otch_`i' = (l_import_`d'_LT_otch - l_import_`d'_LT_otch[_n-`i'])/`i'

		label var d_`d'_LT_usch_`i' "Full `d'stream change in U.S. imports from China;`i' year change"
		label var d_`d'_LT_otch_`i' "Full `d'stream change in comparison countries' imports from China; `i' year change"
	}
}

label var year ""

sort year sic87dd

save "`tradedir'clean/trade_variables.dta", replace
