**************************************************************************************
/* APPENDIX C TABLE 6: OLS Estimation of the Effects of the China's PNTR Status on
U.S. Employment - with Higher-Order Upstream and Downstream Linkages across Industries
COMBINED MEASURE I (DIRECT + UPSTREAM) 3 columns
COMBINED MEASURE II (DIRECT + UPSTREAM + DOWNSTREAM) 3 columns */

* Last edited : November 21, 2017
***************************************************************************************
set more off
set matsize 1000
clear all

*Program to compute predicted employment losses
capture program drop compute_changes
program define compute_changes
	
	egen pred_d_emp_total = total(pred_d_emp)
	sum pred_d_emp_total 
	drop pred_d_emp*
end


*Define directories
local dir "..." //Insert your directory path
local outdir "`dir'/AGNR-JobFlowsChinaShock/out/"
local datadir "`dir'/AGNR-JobFlowsChinaShock/data/sample/"

*Load dataset
use  "`datadir'main_industry.dta", clear
keep if year < 2012

*Specifying panel
tsset, clear
tsset sic87dd year
sort sic87dd year

*Preparing employment variables
*NETS does not have data for 1991
foreach b in "nets" {
	rename `b'_emp_total `b'_emp
	replace `b'_emp = . if year==1991
}


foreach b in "cbp" "nets"  {

	*log-employment variables
	gen l_`b'_emp=log(`b'_emp)


	foreach t in "7" "8" "12" {
		*log changes
		gen dl_`b'_emp_`t'=(l_`b'_emp-L`t'.l_`b'_emp)*100/`t'
	}
}

*Preparing the NTR gap variable
replace spread=0 if year<2002
replace up_LT_spread=0 if year<2002
replace down_LT_spread=0 if year<2002

*Computing 7, 8 and 12 year differences of the NTR gap variable
foreach t in "7" "8" "12" {
	gen spread_`t' = spread*100/`t'
	gen up_LT_spread_`t' = up_LT_spread*100/`t'
	gen down_LT_spread_`t' = down_LT_spread*100/`t'
}


*Preparing Job Flows data
foreach b in "nets" {
	foreach t in "7" "8" "12" {
		foreach f in "birth" "exp" {
		
		replace `b'_`f'_empchange_`t'=. if year == 1991+`t'
		*log changes
		gen dl_`b'_`f'_`t'=(`b'_`f'_empchange_`t'/L`t'.`b'_emp)*(dl_`b'_emp_`t'/(exp(`t'*dl_`b'_emp_`t'/100)-1))
		
		}
		
		foreach f in "death" "con" {
		
		replace `b'_`f'_empchange_`t'=. if year==1991+`t'
		*log changes
		gen dl_`b'_`f'_`t'=-(`b'_`f'_empchange_`t'/L`t'.`b'_emp)*(dl_`b'_emp_`t'/(exp(`t'*dl_`b'_emp_`t'/100)-1))

		}		
			*extensive margin		
			gen dl_`b'_ext_`t'=dl_`b'_birth_`t'-dl_`b'_death_`t'
			*intensive margin
			gen dl_`b'_int_`t'=dl_`b'_exp_`t'-dl_`b'_con_`t'
			*job creation
			gen dl_`b'_cre_`t'=dl_`b'_birth_`t'+dl_`b'_exp_`t'
			*job destruction
			gen dl_`b'_des_`t'=dl_`b'_death_`t'+dl_`b'_con_`t'
	}
}

*Generate YEAR and SECTOR-YEAR DUMMIES (about 210 of them)

qui tab year, gen(yeard)
gen sectors=sector1+2*sector2+3*sector3+4*sector4+5*sector5+6*sector6+7*sector7+8*sector8+9*sector9+10*sector10
gen sectoryear=ln(sectors+1)*ln(year)
qui tab sectoryear, gen(sectoryeard)

*Generate YEAR-MANUF-NON-MANUF dummies

gen bigsectoryear=(1+manuf)*year
qui tab bigsectoryear, gen(mannonmand)

*You could also add dummies in the regression by adding i.year#i.sectors


*Base year for aw weights (1992)

foreach b in "cbp" "nets"  {
	gen `b'_emp1992=`b'_emp
	replace `b'_emp1992=F.`b'_emp1992 if year==1991
	
		forvalues i = 1993/2011 {
			replace `b'_emp1992=L.`b'_emp1992 if year==`i'
		}
		
	gen `b'_emp1993=`b'_emp
	replace `b'_emp1993=F.`b'_emp1993 if year==1992
	replace `b'_emp1993=F.`b'_emp1993 if year==1991
		
		forvalues i = 1994/2012 {
			replace `b'_emp1993=L.`b'_emp1993 if year==`i'
		}
}

gen cbp_emp1991=cbp_emp
	
	forvalues i = 1992/2011 {
		replace cbp_emp1991=L.cbp_emp1991 if year==`i'
	}
	


*Generating zeros for manuf-sector dummies in non-manufacturing industries
forvalues t = 1/10 {
	replace sector`t'=0 if manuf==0
}


estimates clear


	**************generating conditions and controls*******************************
	local window07 year==2007
	local window99 year==1999
	local window9211 year==1999 | year==2011
	local window9207 year==1999 | year==2007


	* Controls
	local time_controls yeard*
	local sector_controls sector1-sector10
	local sectoryear_controls sectoryeard*
	local bigsectoryear_controls mannonmand*
	local prod_controls "ind_prodwemp_1991 ind_lnavgw_1991 ind_capvadd_1991 ind_ci_1990 ind_htsh1_1990"
    local pretrend_controls "d_ind_shemp_7691 d_ind_lnavgw_7691"
	
	
	* Specify weighting and clustering
	gen sic3=int(sic87dd/10)
	local aw "[aw = nets_emp1992]"
	local vce "vce(cluster sic3)"
	local options "noconstant vce(cluster sic3)"
	local optionsxt "fe cluster(sic3)"
	
	* Variables needed to calculate predicted employment losses
	foreach f in "nets_emp" "cbp_emp" {

	gen `f'_2011 = `f' if year == 2011
	gen `f'_2007 = `f' if year == 2007
	gen `f'_1999 = `f' if year == 1999

	}
	
	* Factor to undo annualization
	gen lambda_9211 = 100/(2011 - 1992) 
	gen lambda_9207 = 100/(2007 - 1992)
	gen lambda_9299 = 100/(1999 - 1992)
	gen lambda_9911 = 100/(2011 - 1999)
	gen lambda_9907 = 100/(2007 - 1999)



** Creating stacked variables for 1992-1999-2005-2011 or 1992-1999-2011

foreach b in "cbp" "nets" {

	gen dl_`b'_emp_9211=dl_`b'_emp_12
	replace dl_`b'_emp_9211=dl_`b'_emp_7 if year==1999
}

foreach f in "nets_birth" "nets_death" "nets_exp" "nets_con" "nets_ext" "nets_int" "nets_cre" "nets_des" {

	gen dl_`f'_9211=dl_`f'_12
	replace dl_`f'_9211=dl_`f'_7 if year==1999	
	
}
	
foreach f in "spread" "up_LT_spread" "down_LT_spread" {

	gen `f'_9211=`f'_12
	replace `f'_9211=`f'_7 if year==1999	
	
}
	
	
*Omnibus variables
gen spread_omnibus_LT_9211=spread_9211+up_LT_spread_9211

*Magni variables
gen spread_magni_LT_9211=spread_9211+up_LT_spread_9211+down_LT_spread_9211


*Creating stacked variables for 1992-1999, 1999-2007

foreach b in "cbp" "nets" {

	gen dl_`b'_emp_9207=dl_`b'_emp_8
	replace dl_`b'_emp_9207=dl_`b'_emp_7 if year==1999

}

foreach f in "spread" "up_LT_spread" "down_LT_spread" {

	gen `f'_9207=`f'_8
	replace `f'_9207=`f'_7 if year==1999	
	
}
	
foreach f in "nets_birth" "nets_death" "nets_exp" "nets_con" "nets_ext" "nets_int" "nets_cre" "nets_des" {
		
	gen dl_`f'_9207=dl_`f'_8
	replace dl_`f'_9207=dl_`f'_7 if year==1999	
	
}



*Omnibus variable
gen spread_omnibus_LT_9207=spread_9207+up_LT_spread_9207

*Magni variable
gen spread_magni_LT_9207=spread_9207+up_LT_spread_9207+down_LT_spread_9207


***REGRESSIONS and Calculations of Predicted Employment Losses

* Regressions with NETS total employment
gen pfactor = 0.66

foreach f in "nets_emp" {

	*Column (1)
	eststo m1_`f':regress dl_`f'_9207  spread_omnibus_LT_9207  `sector_controls' `bigsectoryear_controls' `aw' if  `window9207' , `options'
	
	gen pred_d_emp = .
	replace pred_d_emp = `f'_2007 * (1 - exp(-1 * (1/lambda_9907) * (_b[spread_omnibus_LT_9207] * spread_omnibus_LT_9207))) if year==2007
	compute_changes 

	*Column (2)
	eststo m2_`f':regress dl_`f'_9207  spread_omnibus_LT_9207  `bigsectoryear_controls' `aw' if  `window9207' , `options'
	
	gen pred_d_emp = .
	replace pred_d_emp = `f'_2007 * (1 - exp(-1 * (1/lambda_9907) * (_b[spread_omnibus_LT_9207] * spread_omnibus_LT_9207))) if year==2007
	compute_changes 
	
	
	*Column (3)
	eststo m3_`f':regress dl_`f'_9211  spread_omnibus_LT_9211  `bigsectoryear_controls' `aw' if  `window9211' , `options'
	
	gen pred_d_emp = .
	replace pred_d_emp = `f'_2011 * (1 - exp(-1 * (1/lambda_9911) * (_b[spread_omnibus_LT_9211] * spread_omnibus_LT_9211))) if year==2011
	compute_changes

	*Column (4) 
	eststo m4_`f':regress dl_`f'_9207  spread_magni_LT_9207  `sector_controls' `bigsectoryear_controls' `aw' if  `window9207' , `options'
	
	gen pred_d_emp = .
	replace pred_d_emp = `f'_2007 * (1 - exp(-1 * (1/lambda_9907) * (_b[spread_magni_LT_9207] * spread_magni_LT_9207))) if year==2007
	compute_changes
	
	*Column (5) 
	eststo m5_`f':regress dl_`f'_9207  spread_magni_LT_9207 `bigsectoryear_controls' `aw' if  `window9207' , `options'
	
	gen pred_d_emp = .
	replace pred_d_emp = `f'_2007 * (1 - exp(-1 * (1/lambda_9907) * (_b[spread_magni_LT_9207] * spread_magni_LT_9207))) if year==2007
	compute_changes

	*Column (6) 
	eststo m6_`f':regress dl_`f'_9211  spread_magni_LT_9211 `bigsectoryear_controls' `aw' if  `window9211' , `options'
	
	gen pred_d_emp = .
	replace pred_d_emp = `f'_2011 * (1 - exp(-1 * (1/lambda_9911) * (_b[spread_magni_LT_9211] * spread_magni_LT_9211))) if year==2011
	compute_changes
}

* Regressions with Job Flows
 
 foreach f in "nets_birth" "nets_death" "nets_exp" "nets_con" "nets_ext" "nets_int" "nets_cre" "nets_des" {

 	*Column (1) 
	eststo m1_`f':regress dl_`f'_9207  spread_omnibus_LT_9207  `sector_controls' `bigsectoryear_controls' `aw' if  `window9207' , `options'
	
	*Column (2) 
	eststo m2_`f':regress dl_`f'_9207  spread_omnibus_LT_9207  `bigsectoryear_controls' `aw' if  `window9207' , `options'
	
	*Column (3) 
	eststo m3_`f':regress dl_`f'_9211  spread_omnibus_LT_9211  `bigsectoryear_controls' `aw' if  `window9211' , `options'
	
	*Column (4) 
	eststo m4_`f':regress dl_`f'_9207  spread_magni_LT_9207  `sector_controls' `bigsectoryear_controls' `aw' if  `window9207' , `options'
	
	*Column (5) 
	eststo m5_`f':regress dl_`f'_9207  spread_magni_LT_9207 `bigsectoryear_controls' `aw' if  `window9207' , `options'
	
	*Column (6) 
	eststo m6_`f':regress dl_`f'_9211  spread_magni_LT_9211 `bigsectoryear_controls' `aw' if  `window9211' , `options'


}

*Regressions with CBP data
local aw "[aw = cbp_emp1992]"
replace pfactor=0.60
	
	foreach f in  "cbp_emp" {
	
	*Column (1)
	eststo m1_`f':regress dl_`f'_9207  spread_omnibus_LT_9207  `sector_controls' `bigsectoryear_controls' `aw' if  `window9207' , `options'
	
	gen pred_d_emp = .
	replace pred_d_emp = `f'_2007 * (1 - exp(-1 * (1/lambda_9907) * (_b[spread_omnibus_LT_9207] * spread_omnibus_LT_9207))) if year==2007
	compute_changes 

	*Column (2)
	eststo m2_`f':regress dl_`f'_9207  spread_omnibus_LT_9207  `bigsectoryear_controls' `aw' if  `window9207' , `options'
	
	gen pred_d_emp = .
	replace pred_d_emp = `f'_2007 * (1 - exp(-1 * (1/lambda_9907) * (_b[spread_omnibus_LT_9207] * spread_omnibus_LT_9207))) if year==2007
	compute_changes 
	
	*Column (3)
	eststo m3_`f':regress dl_`f'_9211  spread_omnibus_LT_9211  `bigsectoryear_controls' `aw' if  `window9211' , `options'
	
	gen pred_d_emp = .
	replace pred_d_emp = `f'_2011 * (1 - exp(-1 * (1/lambda_9911) * (_b[spread_omnibus_LT_9211] * spread_omnibus_LT_9211))) if year==2011
	compute_changes

	*Column (4) 
	eststo m4_`f':regress dl_`f'_9207  spread_magni_LT_9207  `sector_controls' `bigsectoryear_controls' `aw' if  `window9207' , `options'
	
	gen pred_d_emp = .
	replace pred_d_emp = `f'_2007 * (1 - exp(-1 * (1/lambda_9907) * (_b[spread_magni_LT_9207] * spread_magni_LT_9207))) if year==2007
	compute_changes
	
	*Column (5) 
	eststo m5_`f':regress dl_`f'_9207  spread_magni_LT_9207 `bigsectoryear_controls' `aw' if  `window9207' , `options'
	
	gen pred_d_emp = .
	replace pred_d_emp = `f'_2007 * (1 - exp(-1 * (1/lambda_9907) * (_b[spread_magni_LT_9207] * spread_magni_LT_9207))) if year==2007
	compute_changes

	*Column (6) 
	eststo m6_`f':regress dl_`f'_9211  spread_magni_LT_9211 `bigsectoryear_controls' `aw' if  `window9211' , `options'
	
	gen pred_d_emp = .
	replace pred_d_emp = `f'_2011 * (1 - exp(-1 * (1/lambda_9911) * (_b[spread_magni_LT_9211] * spread_magni_LT_9211))) if year==2011
	compute_changes
}
	

foreach f in "nets_emp" "nets_birth" "nets_death" "nets_exp" "nets_con" "nets_ext" "nets_int" "nets_cre" "nets_des" "cbp_emp" {

	esttab m1_`f' m2_`f' m3_`f' m4_`f' m5_`f' m6_`f' using "`outdir'appc_tab6.csv", b(%9.2f) se(%9.2f) star(* .10 ** .05 *** .01) replace
	insheet using "`outdir'appc_tab6.csv", comma clear
	export excel "`outdir'appc_tab6.xlsx", sheetreplace sheet(appc_tab6_`f')

}
